@@ -44,6 +44,14 @@ func getData(s *v1.Secret) map[string][]byte {
 	return s.Data
 }
 
+func getAnnotations(s *v1.Secret) map[string]string {
+	return s.ObjectMeta.Annotations
+}
+
+func getLabels(s *v1.Secret) map[string]string {
+	return s.ObjectMeta.Labels
+}
+
 func getStatus(ss *ssv1alpha1.SealedSecret) *ssv1alpha1.SealedSecretStatus {
 	return ss.Status
 }
@@ -53,6 +61,10 @@ func getFirstOwnerName(s *v1.Secret) string {
 	return s.OwnerReferences[0].Name
 }
 
+func getNumberOfOwners(s *v1.Secret) int {
+	return len(s.OwnerReferences)
+}
+
 func getSecretType(s *v1.Secret) v1.SecretType {
 	return s.Type
 }
@@ -267,29 +279,142 @@ var _ = Describe("create", func() {
 	Describe("Secret already exists", func() {
 		Context("With managed annotation", func() {
 			BeforeEach(func() {
+				s.Data = map[string][]byte{
+					"foo":  []byte("bar1"),
+					"foo2": []byte("bar2"),
+				}
 				s.Annotations = map[string]string{
 					ssv1alpha1.SealedSecretManagedAnnotation: "true",
 				}
+				s.Labels["anotherlabel"] = "anothervalue"
 				c.Secrets(ns).Create(ctx, s, metav1.CreateOptions{})
 			})
-			It("should manage existing Secret", func() {
-				expected := map[string][]byte{
+			It("should take ownership of the existing Secret overwriting the whole Secret", func() {
+				expectedData := map[string][]byte{
 					"foo": []byte("bar"),
 				}
-				Eventually(func() (*v1.Secret, error) {
-					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
-				}, Timeout, PollingInterval).Should(WithTransform(getData, Equal(expected)))
+				var expectedAnnotations map[string]string
+				expectedLabels := map[string]string{
+					"mylabel": "myvalue",
+				}
 				Eventually(func() (*v1.EventList, error) {
 					return c.Events(ns).Search(scheme.Scheme, ss)
 				}, Timeout, PollingInterval).Should(
 					containEventWithReason(Equal("Unsealed")),
 				)
-				Eventually(func() (*v1.Secret, error) {
-					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
-				}, Timeout, PollingInterval).Should(WithTransform(getFirstOwnerName, Equal(ss.GetName())))
 				Eventually(func() (*ssv1alpha1.SealedSecret, error) {
 					return ssc.BitnamiV1alpha1().SealedSecrets(ns).Get(context.Background(), secretName, metav1.GetOptions{})
 				}, Timeout, PollingInterval).ShouldNot(WithTransform(getStatus, BeNil()))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getFirstOwnerName, Equal(ss.GetName())))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getData, Equal(expectedData)))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getAnnotations, Equal(expectedAnnotations)))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getLabels, Equal(expectedLabels)))
+			})
+		})
+
+		Context("With managed and patch annotation", func() {
+			BeforeEach(func() {
+				s.Data = map[string][]byte{
+					"foo":  []byte("bar1"),
+					"foo2": []byte("bar2"),
+				}
+				s.Annotations = map[string]string{
+					ssv1alpha1.SealedSecretManagedAnnotation: "true",
+					ssv1alpha1.SealedSecretPatchAnnotation:   "true",
+				}
+				s.Labels["anotherlabel"] = "anothervalue"
+				c.Secrets(ns).Create(ctx, s, metav1.CreateOptions{})
+			})
+
+			It("should take ownership of the existing Secret patching instead of overwriting the whole Secret", func() {
+				expectedData := map[string][]byte{
+					"foo":  []byte("bar"),
+					"foo2": []byte("bar2"),
+				}
+				expectedAnnotations := map[string]string{
+					ssv1alpha1.SealedSecretManagedAnnotation: "true",
+					ssv1alpha1.SealedSecretPatchAnnotation:   "true",
+				}
+				expectedLabels := map[string]string{
+					"mylabel":      "myvalue",
+					"anotherlabel": "anothervalue",
+				}
+				Eventually(func() (*v1.EventList, error) {
+					return c.Events(ns).Search(scheme.Scheme, ss)
+				}, Timeout, PollingInterval).Should(
+					containEventWithReason(Equal("Unsealed")),
+				)
+				Eventually(func() (*ssv1alpha1.SealedSecret, error) {
+					return ssc.BitnamiV1alpha1().SealedSecrets(ns).Get(context.Background(), secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).ShouldNot(WithTransform(getStatus, BeNil()))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getFirstOwnerName, Equal(ss.GetName())))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getData, Equal(expectedData)))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getAnnotations, Equal(expectedAnnotations)))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getLabels, Equal(expectedLabels)))
+			})
+		})
+
+		Context("With patch annotation", func() {
+			BeforeEach(func() {
+				s.Data = map[string][]byte{
+					"foo":  []byte("bar1"),
+					"foo2": []byte("bar2"),
+				}
+				s.Annotations = map[string]string{
+					ssv1alpha1.SealedSecretPatchAnnotation: "true",
+				}
+				s.Labels["anotherlabel"] = "anothervalue"
+				c.Secrets(ns).Create(ctx, s, metav1.CreateOptions{})
+			})
+
+			It("should not take ownership of existing Secret while patching the Secret", func() {
+				expectedData := map[string][]byte{
+					"foo":  []byte("bar"),
+					"foo2": []byte("bar2"),
+				}
+				expectedAnnotations := map[string]string{
+					ssv1alpha1.SealedSecretPatchAnnotation: "true",
+				}
+				expectedLabels := map[string]string{
+					"mylabel":      "myvalue",
+					"anotherlabel": "anothervalue",
+				}
+				Eventually(func() (*v1.EventList, error) {
+					return c.Events(ns).Search(scheme.Scheme, ss)
+				}, Timeout, PollingInterval).Should(
+					containEventWithReason(Equal("Unsealed")),
+				)
+				Eventually(func() (*ssv1alpha1.SealedSecret, error) {
+					return ssc.BitnamiV1alpha1().SealedSecrets(ns).Get(context.Background(), secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).ShouldNot(WithTransform(getStatus, BeNil()))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getNumberOfOwners, Equal(0)))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getData, Equal(expectedData)))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getAnnotations, Equal(expectedAnnotations)))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getLabels, Equal(expectedLabels)))
 			})
 		})
 	})
@@ -323,6 +448,7 @@ var _ = Describe("create", func() {
 
 		Context("With unowned secret with managed annotation", func() {
 			BeforeEach(func() {
+				s.Data["foo2"] = []byte("bar2")
 				s.Annotations = map[string]string{
 					ssv1alpha1.SealedSecretManagedAnnotation: "true",
 				}
@@ -336,9 +462,6 @@ var _ = Describe("create", func() {
 				expected := map[string][]byte{
 					"foo": []byte("bar"),
 				}
-				Eventually(func() (*v1.Secret, error) {
-					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
-				}, Timeout, PollingInterval).Should(WithTransform(getData, Equal(expected)))
 				Eventually(func() (*v1.EventList, error) {
 					return c.Events(ns).Search(scheme.Scheme, ss)
 				}, Timeout, PollingInterval).Should(
@@ -347,6 +470,9 @@ var _ = Describe("create", func() {
 				Eventually(func() (*v1.Secret, error) {
 					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
 				}, Timeout, PollingInterval).Should(WithTransform(getFirstOwnerName, Equal(ss.GetName())))
+				Eventually(func() (*v1.Secret, error) {
+					return c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+				}, Timeout, PollingInterval).Should(WithTransform(getData, Equal(expected)))
 			})
 		})
 
@@ -366,6 +492,31 @@ var _ = Describe("create", func() {
 				}).Should(WithTransform(errors.IsNotFound, Equal(true)))
 			})
 		})
+
+		Context("With unowned secret with patch annotation", func() {
+			BeforeEach(func() {
+				s.Data = map[string][]byte{
+					"foo":  []byte("bar1"),
+					"foo2": []byte("bar2"),
+				}
+				s.Annotations = map[string]string{
+					ssv1alpha1.SealedSecretPatchAnnotation: "true",
+				}
+				s.Labels["anotherlabel"] = "anothervalue"
+				c.Secrets(ns).Create(ctx, s, metav1.CreateOptions{})
+			})
+			JustBeforeEach(func() {
+				err := c.Secrets(ns).Delete(ctx, secretName, metav1.DeleteOptions{})
+				Expect(err).NotTo(HaveOccurred())
+			})
+
+			It("should not recreate the secret", func() {
+				Consistently(func() error {
+					_, err := c.Secrets(ns).Get(ctx, secretName, metav1.GetOptions{})
+					return err
+				}).Should(WithTransform(errors.IsNotFound, Equal(true)))
+			})
+		})
 	})
 
 	Describe("Same name, wrong key", func() {
