@@ -57,7 +57,7 @@ const (
 )
 
 var (
-	// ErrCast happens when a K8s any type cannot be casted to the expected type
+	// ErrCast happens when a K8s any type cannot be casted to the expected type.
 	ErrCast = errors.New("cast error")
 )
 
@@ -200,7 +200,7 @@ func watchSecrets(sinformer informers.SharedInformerFactory, ssclientset ssclien
 }
 
 // HasSynced returns true once this controller has completed an
-// initial resource listing
+// initial resource listing.
 func (c *Controller) HasSynced() bool {
 	var synced bool
 	if c.sInformer == nil {
@@ -339,7 +339,7 @@ func (c *Controller) unseal(ctx context.Context, key string) (unsealErr error) {
 		return err
 	}
 
-	if !metav1.IsControlledBy(secret, ssecret) && !isAnnotatedToBeManaged(secret) {
+	if !metav1.IsControlledBy(secret, ssecret) && !isAnnotatedToBeManaged(secret) && !isAnnotatedToBePatched(secret) {
 		msg := fmt.Sprintf("Resource %q already exists and is not managed by SealedSecret", secret.Name)
 		c.recorder.Event(ssecret, corev1.EventTypeWarning, ErrUpdateFailed, msg)
 		unsealErrorsTotal.WithLabelValues("unmanaged", ssecret.GetNamespace()).Inc()
@@ -349,11 +349,30 @@ func (c *Controller) unseal(ctx context.Context, key string) (unsealErr error) {
 	origSecret := secret
 	secret = secret.DeepCopy()
 
-	secret.Data = newSecret.Data
+	if isAnnotatedToBePatched(secret) {
+		for k, v := range newSecret.Data {
+			secret.Data[k] = v
+		}
+
+		for k, v := range newSecret.ObjectMeta.Annotations {
+			secret.ObjectMeta.Annotations[k] = v
+		}
+
+		for k, v := range newSecret.ObjectMeta.Labels {
+			secret.ObjectMeta.Labels[k] = v
+		}
+
+		if isAnnotatedToBeManaged(secret) {
+			secret.ObjectMeta.OwnerReferences = newSecret.ObjectMeta.OwnerReferences
+		}
+	} else {
+		secret.Data = newSecret.Data
+		secret.ObjectMeta.Annotations = newSecret.ObjectMeta.Annotations
+		secret.ObjectMeta.Labels = newSecret.ObjectMeta.Labels
+		secret.ObjectMeta.OwnerReferences = newSecret.ObjectMeta.OwnerReferences
+	}
+
 	secret.Type = newSecret.Type
-	secret.ObjectMeta.Annotations = newSecret.ObjectMeta.Annotations
-	secret.ObjectMeta.OwnerReferences = newSecret.ObjectMeta.OwnerReferences
-	secret.ObjectMeta.Labels = newSecret.ObjectMeta.Labels
 
 	if !apiequality.Semantic.DeepEqual(origSecret, secret) {
 		_, err = c.sclient.Secrets(ssecret.GetObjectMeta().GetNamespace()).Update(ctx, secret, metav1.UpdateOptions{})
@@ -435,11 +454,14 @@ func updateSealedSecretsStatusConditions(st *ssv1alpha1.SealedSecretStatus, unse
 	}
 }
 
-// checks if the annotation equals to "true", and it's case-sensitive
 func isAnnotatedToBeManaged(secret *corev1.Secret) bool {
 	return secret.Annotations[ssv1alpha1.SealedSecretManagedAnnotation] == "true"
 }
 
+func isAnnotatedToBePatched(secret *corev1.Secret) bool {
+	return secret.Annotations[ssv1alpha1.SealedSecretPatchAnnotation] == "true"
+}
+
 // AttemptUnseal tries to unseal a secret.
 func (c *Controller) AttemptUnseal(content []byte) (bool, error) {
 	if err := multidocyaml.EnsureNotMultiDoc(content); err != nil {
